:mod:`anyconfig.backend.python`
=====================================

.. automodule:: anyconfig.backend.python
    :members:
    :special-members:
    :private-members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   anyconfig.backend.python.builtin
   anyconfig.backend.python.loader
   anyconfig.backend.python.dumper
